@@ -1304,17 +1304,17 @@ void AppleTAS3004Audio::setEQProcessing (void * inEQStructure, Boolean inRealtim
 
 IOReturn AppleTAS3004Audio::setBiquadCoefficients ( void * biquadCoefficients )
 {
-	IOReturn		err;
-	IOReturn		totalErr = kIOReturnError;
-
-	totalErr = kIOReturnSuccess;
+	IOReturn				err;
+	IOReturn				totalErr = kIOReturnSuccess;
+	EQFilterCoefficients*	biquadCoefficientsPtr = (EQFilterCoefficients*) biquadCoefficients;
+	
 	for ( UInt32 index = 0; index < ( kTAS3004NumBiquads * kTAS3004MaxStreamCnt ); index ++ ) {
 		if ( kTAS3004NumBiquads > index ) {
-			err = SndHWSetOutputBiquad ( kStreamFrontLeft, index, (FourDotTwenty*)biquadCoefficients );
+			err = SndHWSetOutputBiquad ( kStreamFrontLeft, index, (FourDotTwenty*)biquadCoefficientsPtr );
 		} else {
-			err = SndHWSetOutputBiquad ( kStreamFrontRight, index - kTAS3004NumBiquads, (FourDotTwenty*)biquadCoefficients );
+			err = SndHWSetOutputBiquad ( kStreamFrontRight, index - kTAS3004NumBiquads, (FourDotTwenty*)biquadCoefficientsPtr );
 		}
-		(( EQFilterCoefficients*)biquadCoefficients)++;
+		biquadCoefficientsPtr++;
 		if ( err ) { totalErr = err; }
 	}
 	return totalErr;
